# (akien) The Vulkan SDK requires some care when updating.
# Check instructions in the vulkan-headers spec file.

# (akien) No soname upstream, arbitrarily using 0 for now
# Without proper soname, the devel package would not generate the
# devel() provides that RPM relies on to pull in the proper deps
# in reverse dependencies.
%define major   15
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d

# Cyclic dependencies between HLSL and glslang, we can't build with --no-undefined
# for the time being: https://github.com/KhronosGroup/glslang/issues/1484
%define _disable_ld_no_undefined 1

Name:           glslang
# Check tag matching Vulkan sdk-* tag used for other Vulkan components.
Version:        15.0.0
Release:        %mkrel 1
Summary:        Khronos reference front-end for GLSL and ESSL, and sample SPIR-V generator
Group:          System/Libraries
License:        BSD and GPLv3+ and ASL 2.0
URL:            https://github.com/KhronosGroup/glslang
Source0:        https://github.com/KhronosGroup/glslang/archive/%{version}/%{name}-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  pkgconfig(SPIRV-Tools) >= 2024.4
BuildRequires:  python3-devel

%description
%{name} is the official reference compiler front end for the OpenGL
ES and OpenGL shading languages. It implements a strict
interpretation of the specifications for these languages.

%package -n %{libname}
Summary:        Library files for glslang
Group:          System/Libraries

%description -n %{libname}
Library files for glslang.

%package -n %{devname}
Summary:        Development files for glslang
Requires:       %{name} = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
%{name} is the official reference compiler front end for the OpenGL
ES and OpenGL shading languages. It implements a strict
interpretation of the specifications for these languages.

%prep
%autosetup -p1

%build
%cmake -GNinja \
       -DALLOW_EXTERNAL_SPIRV_TOOLS:BOOL=ON \
       -DENABLE_OPT:BOOL=ON
%cmake_build

%install
%cmake_install

%check
pushd Test
LD_LIBRARY_PATH+=%{buildroot}%{_libdir} ./runtests localResults \
  %{buildroot}%{_bindir}/glslangValidator \
  %{buildroot}%{_bindir}/spirv-remap
popd

%files
%doc README.md README-spirv-remap.txt
%{_bindir}/glslang
%{_bindir}/glslangValidator
%{_bindir}/spirv-remap

%files -n %{libname}
%{_libdir}/lib%{name}*.so.%{major}
%{_libdir}/lib%{name}*.so.%{version}
%{_libdir}/libSPIRV.so.%{major}
%{_libdir}/libSPIRV.so.%{version}
%{_libdir}/libSPVRemapper.so.%{major}
%{_libdir}/libSPVRemapper.so.%{version}

%files -n %{devname}
%{_includedir}/%{name}/
%{_libdir}/cmake/%{name}/
%{_libdir}/lib%{name}*.so
%{_libdir}/libSPIRV.so
%{_libdir}/libSPVRemapper.so


%changelog
* Fri Nov 15 2024 daviddavid <daviddavid> 15.0.0-1.mga10
+ Revision: 2116032
- update to 1.3.296.0 SDK
- now libmajor is 15

* Tue Aug 20 2024 daviddavid <daviddavid> 14.3.0-1.mga10
+ Revision: 2087106
- update to 1.3.290.0 SDK
- now libmajor is 14
+ wally <wally>
- pull main pkg with the devel one

* Mon Nov 14 2022 akien <akien> 11.12.0-1.mga9
+ Revision: 1907214
- Version 11.12.0, Vulkan SDK 1.3.231.1

* Sat Mar 19 2022 umeabot <umeabot> 11.8.0-2.2742e95.mga9
+ Revision: 1799681
- Mageia 9 Mass Rebuild

* Mon Mar 07 2022 akien <akien> 11.8.0-1.2742e95.mga9
+ Revision: 1789544
- Version 11.8.0, Vulkan SDK 1.3.204.1

* Wed Dec 30 2020 akien <akien> 11.0.0-1.dd69df7.mga8
+ Revision: 1666495
- Commit dd69df7, matching requirements for Vulkan SDK 1.2.162.0

* Mon Oct 12 2020 akien <akien> 11.0.0-1.bacaef3.mga8
+ Revision: 1633970
- Version 11.0.0 (needed for Vulkan SDK 1.2.154.0)
- Rebase patches and submit them upstream

* Mon Feb 17 2020 akien <akien> 8.13.3559-1.4fc7a33.mga8
+ Revision: 1536928
- Commit 4fc7a33, necessary for Vulkan SDK 1.2.131.2

* Sun Feb 16 2020 umeabot <umeabot> 7.12.3381-2.3495381.mga8
+ Revision: 1533962
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Wed Sep 25 2019 akien <akien> 7.12.3381-1.3495381.mga8
+ Revision: 1445857
- Commit 3495381, necessary for Vulkan SDK 1.1.121.0

* Thu Apr 18 2019 akien <akien> 7.11.3113-4.e06c7e9.mga7
+ Revision: 1393159
- Commit e06c7e9, matching requirements from Vulkan SDK 1.1.106.0

* Wed Mar 27 2019 akien <akien> 7.11.3113-3.5432f0d.mga7
+ Revision: 1380636
- Rebuild against updated spirv-headers and spirv-tools, needed to be able to build vulkan-validation-layers 1.1.101.0

* Wed Mar 27 2019 akien <akien> 7.11.3113-2.5432f0d.mga7
+ Revision: 1380629
- Update to git commit 5432f0d, known_good version for Vulkan SDK 1.1.101.0

* Tue Mar 26 2019 akien <akien> 7.11.3113-1.mga7
+ Revision: 1380460
- Version 7.11.3113

* Tue Dec 11 2018 akien <akien> 7.10.2984-3.mga7
+ Revision: 1340227
- Rebuild to pick updated spirv-tools on armv7hl

* Tue Dec 11 2018 akien <akien> 7.10.2984-2.mga7
+ Revision: 1340206
- Properly libify with defined soname (major 0 for now)

* Mon Dec 10 2018 akien <akien> 7.10.2984-1.mga7
+ Revision: 1339877
- Adapt to Mageia's library policy
- Build as shared libraries
- Build against system SPIRV-Tools for HLSL support
- Fix underlinking of OSDependent (other underlinking issues remain in HLSL)
- import glslang from Fedora Rawhide


* Tue Aug 07 2018 Leigh Scott <leigh123linux@googlemail.com> - 3.1-0.10.20180727.gite99a268
- Update for vulkan 1.1.82.0

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 3.1-0.9.20180416.git3bb4c48
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Mon Apr 23 2018 Leigh Scott <leigh123linux@googlemail.com> - 3.1-0.8.20180416.git3bb4c48
- Update for vulkan 1.1.73.0

* Wed Mar 07 2018 Adam Williamson <awilliam@redhat.com> - 3.1-0.7.20180205.git2651cca
- Rebuild to fix GCC 8 mis-compilation
  See https://da.gd/YJVwk ("GCC 8 ABI change on x86_64")

* Fri Feb 09 2018 Leigh Scott <leigh123linux@googlemail.com> - 3.1-0.6.20180205.git2651cca
- Update for vulkan 1.0.68.0

* Fri Feb 09 2018 Leigh Scott <leigh123linux@googlemail.com> - 3.1-0.5.20171028.git715c353
- Use ninja to build

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 3.1-0.4.20171028.git715c353
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Jan 03 2018 Leigh Scott <leigh123linux@googlemail.com> - 3.1-0.3.20171028.git715c353
- Exclude s390x and ppc64 from check section

* Wed Jan 03 2018 Leigh Scott <leigh123linux@googlemail.com> - 3.1-0.2.20171028.git715c353
- Add check section to run tests
- Split binaries into main package

* Thu Jul 13 2017 Leigh Scott <leigh123linux@googlemail.com> - 3.1-0.1.20171028.git715c353
- First build

